@@ -6,3 +6,5 @@ class FilterOperator(enum.Enum):
     DIFFERENT = 'diferent'
     GREATER_THAN = 'greater_than'
     LESS_THAN = 'less_than'
+    LIKE = "like"
+    ILIKE = "ilike"
\ No newline at end of file
